pub struct VapiAdapter { /* private fields */ }Expand description
An outbound-only Vapi interop adapter.
Implementations
Sourceimpl VapiAdapter
impl VapiAdapter
pub fn new(config: VapiConfig) -> Result<Arc<Self>>
pub fn subscribe_vapi_events(&self) -> Receiver<VapiEventEnvelope>
pub fn subscribe_call_events( &self, connection_id: &ConnectionId, ) -> RvoipResult<Receiver<VapiEvent>>
pub async fn say( &self, connection_id: &ConnectionId, content: impl Into<String>, end_call_after_spoken: bool, interrupt_assistant: bool, ) -> Result<()>
pub async fn add_message( &self, connection_id: &ConnectionId, role: impl Into<String>, content: impl Into<String>, trigger_response: bool, ) -> Result<()>
pub async fn mute_assistant(&self, connection_id: &ConnectionId) -> Result<()>
pub async fn unmute_assistant(&self, connection_id: &ConnectionId) -> Result<()>
Sourceimpl VapiAdapter
impl VapiAdapter
Sourcepub async fn attach_agent(
self: &Arc<Self>,
orchestrator: &Arc<Orchestrator>,
caller_connection_id: ConnectionId,
options: VapiCallOptions,
) -> RvoipResult<VapiAgentCall>
pub async fn attach_agent( self: &Arc<Self>, orchestrator: &Arc<Orchestrator>, caller_connection_id: ConnectionId, options: VapiCallOptions, ) -> RvoipResult<VapiAgentCall>
Originate a Vapi WebSocket call and bridge it to an existing caller.
The adapter registers itself when no Vapi adapter is registered. A different pre-existing Vapi adapter is rejected to keep route ownership exact.